@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 13367 2021-12-24 04:53:31Z Mint $
+# $Id: __init__.py 13375 2022-01-15 08:57:05Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Mint $ (last)
-# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
-# $Revision: 13367 $
+# $Author: Lavender $ (last)
+# $Date: 2022-01-15 16:57:05 +0800 (週六, 15 一月 2022) $
+# $Revision: 13375 $
 
 import os
 import sys
@@ -98,8 +98,8 @@ def attachSettings(settingsDict):
         'Zephyrus.line',
         'Zephyrus.comment',
         'Zephyrus.stats',
-        # 'drip',
-        # 'Zephyrus.autoresponder',
+        'drip',
+        'Zephyrus.autoresponder',
         'robots',
         'django_gravatar',
         'captcha',
