@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 12420 2020-07-23 08:06:48Z Lavender $
+# $Id: models.py 13375 2022-01-15 08:57:05Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-07-23 16:06:48 +0800 (週四, 23 七月 2020) $
-# $Revision: 12420 $
+# $Date: 2022-01-15 16:57:05 +0800 (週六, 15 一月 2022) $
+# $Revision: 13375 $
 
 import operator
 import functools
@@ -33,8 +33,8 @@ from Zephyrus import createLogger
 logger = createLogger("Drip2", "ZephyrusDrip2.log")
 
 def get_user_model():
-    modelName = getattr(settings, "ZEPHYRUS_AUTORESPONDER_MODEL", "User")
-    if modelName == "User":
+    modelName = getattr(settings, "ZEPHYRUS_AUTORESPONDER_MODEL", "auth.User")
+    if modelName == "auth.User":
         try:
             from django.contrib.auth import (
                 get_user_model as django_get_user_model)
