@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11979 2020-03-18 04:52:03Z Trista $
+# $Id: admin.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,18 +11,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-03-18 12:52:03 +0800 (Wed, 18 Mar 2020) $
-# $Revision: 11979 $
-
-import urllib
-import re
-import six
-import unicodedata
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 from django import forms
 from django.contrib import admin
-from django.conf import settings
 from django.contrib.redirects.models import Redirect
 from django.contrib.sites.shortcuts import get_current_site
 from django.utils.translation import ugettext_lazy as _
@@ -33,16 +27,17 @@ from aldryn_categories.admin import CategoryAdmin
 from aldryn_categories.models import Category
 from djangocms_text_ckeditor.models import Text
 from taggit import models
-from awesome_slugify import Slugify
-
+try:
+    from awesome_slugify import Slugify
+except ModuleNotFoundError:
+    from slugify import Slugify
 from Iuppiter.DjangoUtil import DJANGO_VERSION
 
 if DJANGO_VERSION >= 20000:
-    from django.urls import reverse_lazy
+    from django.urls import reverse_lazy # pylint: disable=C0412
 else:
-    from django.core.urlresolvers import reverse_lazy
+    from django.core.urlresolvers import reverse_lazy# pylint: disable=E0401,C0412
 
-from Zephyrus.blog_extension import views
 from Zephyrus.blog_extension.models import CallToActionStatistics
 
 unicodeSlugify = Slugify(translate=None)
