@@ -9,4 +9,4 @@ pip install -r $HOME/app/templates_shop/ZephyrusEnv/REQUIREMENTS_$1.txt
 pip install -U django-cms==$1
 pip install -U django==2.2.10
 pip install -U djangocms_bootstrap4==1.5.0
-pip install -U html5lib==1.0.1
+pip install -U html5lib==1.1
