@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11461 2019-04-16 18:26:42Z Lavender $
+# $Id: __init__.py 13396 2022-03-21 08:06:38Z Jacky $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-04-17 02:26:42 +0800 (Wed, 17 Apr 2019) $
-# $Revision: 11461 $
+# $Author: Jacky $
+# $Date: 2022-03-21 16:06:38 +0800 (週一, 21 三月 2022) $
+# $Revision: 13396 $
 
 import os
 import logging
@@ -32,7 +32,10 @@ if hasattr(settings, 'TEMPLATES'):
 else:
     TEMPLATES_DIR_PATH = os.path.abspath(
         os.path.join('.', 'templates'))
-    
+
+# To avoid path object.
+TEMPLATES_DIR_PATH = str(TEMPLATES_DIR_PATH)
+
 if settings.DEBUG:
     if hasattr(settings, 'STATICFILES_DIRS'):
         STATIC_DIR_PATH = settings.STATICFILES_DIRS[0]
@@ -45,12 +48,15 @@ else:
     else:
         STATIC_DIR_PATH = os.path.abspath(
             os.path.join('.', 'static'))
-            
+
+# To avoid path object.
+STATIC_DIR_PATH = str(STATIC_DIR_PATH)
+
 FIXTURES_DIR_PATH = os.path.abspath(
     os.path.join('.', 'fixtures'))
-    
+
 IMAGES_DIR_PATH = os.path.abspath(
-    os.path.join('.', 'images')) 
+    os.path.join('.', 'images'))
 
 PROJECT_MASHINES_DIR = os.path.join(
     ROOT_DIR_PATH, "BoilerplateProjects")
@@ -64,7 +70,7 @@ PROJECT_MASHINES_ZIP = os.path.join(
 PROJECT_ENV_REQUIREMENTS = os.path.join(
     os.path.dirname(os.path.abspath(__file__)), "REQUIREMENTS_[VERSION].txt")
 
-if 'Windows' in platform.system(): 
+if 'Windows' in platform.system():
     PROJECT_ENV_SCRIPT = os.path.join(
         os.path.dirname(os.path.abspath(__file__)), "CreateEnv.bat")
 else:
@@ -82,10 +88,10 @@ def createLogger(name, fileHandlerName):
     fileHandler.setLevel(logging.WARNING)
     logger.addHandler(fileHandler)
     return logger
-    
+
 def toBytes(s):
     return s if six.PY2 else s.encode()
-    
+
 def open3(name, mode='r'):
     if six.PY2:
         return open(name, mode)
@@ -348,4 +354,3 @@ CSS_PROPERTIES = [
     'mso-table-lspace',
     'mso-table-rspace',
 ]
-    
\ No newline at end of file
