@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 12544 2020-10-08 06:33:19Z Lavender $
+# $Id: pluginize.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-10-08 14:33:19 +0800 (週四, 08 十月 2020) $
-# $Revision: 12544 $
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import json
@@ -223,45 +223,27 @@ class Placeholder2(Placeholder):
                         hashlib.md5(
                             toBytes(placeholder.slot)).hexdigest(), attrList))
                     
-                    if not cms.__version__.startswith('3.4'):
-                        if root.tag == 'a':
-                            link = root.get('href')
-                            if link == '' or link == None:
-                                link = '#'
-                            Picture.objects.create(
-                                placeholder=placeholder,
-                                language=Placeholder2.lang,
-                                plugin_type='PicturePlugin',
-                                link_url=link,
-                                external_picture=url,
-                                attributes=imgAttrDict,
-                                link_attributes=aAttrDict,
-                            )                    
-                        else:
-                            Picture.objects.create(
-                                placeholder=placeholder,
-                                language=Placeholder2.lang,
-                                plugin_type='PicturePlugin',
-                                external_picture=url,
-                                attributes=imgAttrDict,
-                            )                    
+                    if root.tag == 'a':
+                        link = root.get('href')
+                        if link == '' or link == None:
+                            link = '#'
+                        Picture.objects.create(
+                            placeholder=placeholder,
+                            language=Placeholder2.lang,
+                            plugin_type='PicturePlugin',
+                            link_url=link,
+                            external_picture=url,
+                            attributes=imgAttrDict,
+                            link_attributes=aAttrDict,
+                        )                    
                     else:
-                        from cmsplugin_filer_image.models import FilerImage
-                        if root.tag == 'a':
-                            link = root.get('href')
-                            FilerImage.objects.create(
-                                placeholder=placeholder,
-                                language=Placeholder2.lang,
-                                caption_text='', image_url=url,
-                                plugin_type='FilerImagePlugin',
-                                free_link=link)
-
-                        else:
-                            FilerImage.objects.create(
-                                placeholder=placeholder,
-                                language=Placeholder2.lang,
-                                caption_text='', image_url=url,
-                                plugin_type='FilerImagePlugin',)
+                        Picture.objects.create(
+                            placeholder=placeholder,
+                            language=Placeholder2.lang,
+                            plugin_type='PicturePlugin',
+                            external_picture=url,
+                            attributes=imgAttrDict,
+                        )                    
                     
                 else:
                     try:
