@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12224 2020-05-15 09:54:33Z Andy $
+# $Id: __init__.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2020-05-15 17:54:33 +0800 (週五, 15 五月 2020) $
-# $Revision: 12224 $
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 from django.conf.urls import url, include
 
@@ -37,6 +37,8 @@ def attachURLs(settings, urlpatterns):
     """
     urlpatterns += patterns('',
         url(r'^', include('Zephyrus.landing.urls')),
+        #FIXME: unknown reason have to add a blank (or anything else) behind to make this url works.
+        url(r'^ ', include('djangocms_forms.urls')),
     )
 
 class ErrorCode(object):
